# coding: utf-8

"""
    Merlin

    API Guide for accessing Merlin's model management, deployment, and serving functionalities

    The version of the OpenAPI document: 0.14.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from pydantic import StrictInt, StrictStr

from typing import List, Optional

from client.models.container import Container
from client.models.list_jobs_paginated_response import ListJobsPaginatedResponse
from client.models.prediction_job import PredictionJob

from client.api_client import ApiClient
from client.api_response import ApiResponse
from client.rest import RESTResponseType


class PredictionJobsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def models_model_id_versions_version_id_jobs_by_page_get(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        page: Optional[StrictInt] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListJobsPaginatedResponse:
        """List all prediction jobs of a model version with pagination


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param page:
        :type page: int
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_by_page_get_serialize(
            model_id=model_id,
            version_id=version_id,
            page=page,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_by_page_get_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        page: Optional[StrictInt] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListJobsPaginatedResponse]:
        """List all prediction jobs of a model version with pagination


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param page:
        :type page: int
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_by_page_get_serialize(
            model_id=model_id,
            version_id=version_id,
            page=page,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_by_page_get_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        page: Optional[StrictInt] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List all prediction jobs of a model version with pagination


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param page:
        :type page: int
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_by_page_get_serialize(
            model_id=model_id,
            version_id=version_id,
            page=page,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_by_page_get_serialize(
        self,
        model_id,
        version_id,
        page,
        page_size,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/models/{model_id}/versions/{version_id}/jobs-by-page',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def models_model_id_versions_version_id_jobs_get(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PredictionJob]:
        """(Deprecated) List all prediction jobs of a model version. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /models/{model_id}/versions/{version_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._models_model_id_versions_version_id_jobs_get_serialize(
            model_id=model_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_get_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PredictionJob]]:
        """(Deprecated) List all prediction jobs of a model version. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /models/{model_id}/versions/{version_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._models_model_id_versions_version_id_jobs_get_serialize(
            model_id=model_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_get_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """(Deprecated) List all prediction jobs of a model version. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /models/{model_id}/versions/{version_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._models_model_id_versions_version_id_jobs_get_serialize(
            model_id=model_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_get_serialize(
        self,
        model_id,
        version_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/models/{model_id}/versions/{version_id}/jobs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_containers_get(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Container:
        """Get all container belong to a prediction job


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_containers_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Container",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_containers_get_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Container]:
        """Get all container belong to a prediction job


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_containers_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Container",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_containers_get_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all container belong to a prediction job


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_containers_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Container",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_job_id_containers_get_serialize(
        self,
        model_id,
        version_id,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/models/{model_id}/versions/{version_id}/jobs/{job_id}/containers',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_get(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PredictionJob:
        """Get prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_get_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PredictionJob]:
        """Get prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_get_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_get_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_job_id_get_serialize(
        self,
        model_id,
        version_id,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/models/{model_id}/versions/{version_id}/jobs/{job_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_stop_put(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Stop prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_stop_put_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_stop_put_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Stop prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_stop_put_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_job_id_stop_put_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        job_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Stop prediction jobs with given id


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param job_id: (required)
        :type job_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_job_id_stop_put_serialize(
            model_id=model_id,
            version_id=version_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_job_id_stop_put_serialize(
        self,
        model_id,
        version_id,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/models/{model_id}/versions/{version_id}/jobs/{job_id}/stop',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def models_model_id_versions_version_id_jobs_post(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        body: Optional[PredictionJob] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PredictionJob:
        """Create a prediction job from the given model version


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param body:
        :type body: PredictionJob
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_post_serialize(
            model_id=model_id,
            version_id=version_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_model_id_versions_version_id_jobs_post_with_http_info(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        body: Optional[PredictionJob] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PredictionJob]:
        """Create a prediction job from the given model version


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param body:
        :type body: PredictionJob
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_post_serialize(
            model_id=model_id,
            version_id=version_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_model_id_versions_version_id_jobs_post_without_preload_content(
        self,
        model_id: StrictInt,
        version_id: StrictInt,
        body: Optional[PredictionJob] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a prediction job from the given model version


        :param model_id: (required)
        :type model_id: int
        :param version_id: (required)
        :type version_id: int
        :param body:
        :type body: PredictionJob
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_model_id_versions_version_id_jobs_post_serialize(
            model_id=model_id,
            version_id=version_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PredictionJob",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_model_id_versions_version_id_jobs_post_serialize(
        self,
        model_id,
        version_id,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if version_id is not None:
            _path_params['version_id'] = version_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            _body_params = body


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/models/{model_id}/versions/{version_id}/jobs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def projects_project_id_jobs_by_page_get(
        self,
        project_id: StrictInt,
        page: Optional[StrictInt] = None,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListJobsPaginatedResponse:
        """List all prediction jobs created using the model with pagination


        :param project_id: (required)
        :type project_id: int
        :param page:
        :type page: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._projects_project_id_jobs_by_page_get_serialize(
            project_id=project_id,
            page=page,
            id=id,
            name=name,
            search=search,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def projects_project_id_jobs_by_page_get_with_http_info(
        self,
        project_id: StrictInt,
        page: Optional[StrictInt] = None,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListJobsPaginatedResponse]:
        """List all prediction jobs created using the model with pagination


        :param project_id: (required)
        :type project_id: int
        :param page:
        :type page: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._projects_project_id_jobs_by_page_get_serialize(
            project_id=project_id,
            page=page,
            id=id,
            name=name,
            search=search,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def projects_project_id_jobs_by_page_get_without_preload_content(
        self,
        project_id: StrictInt,
        page: Optional[StrictInt] = None,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        search: Annotated[Optional[StrictStr], Field(description="Search job name for a partial match of the search text")] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of items on each page. It defaults to 10.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List all prediction jobs created using the model with pagination


        :param project_id: (required)
        :type project_id: int
        :param page:
        :type page: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param search: Search job name for a partial match of the search text
        :type search: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param page_size: Number of items on each page. It defaults to 10.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._projects_project_id_jobs_by_page_get_serialize(
            project_id=project_id,
            page=page,
            id=id,
            name=name,
            search=search,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobsPaginatedResponse",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _projects_project_id_jobs_by_page_get_serialize(
        self,
        project_id,
        page,
        id,
        name,
        search,
        model_id,
        version_id,
        status,
        error,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if project_id is not None:
            _path_params['project_id'] = project_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if id is not None:
            
            _query_params.append(('id', id))
            
        if name is not None:
            
            _query_params.append(('name', name))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        if model_id is not None:
            
            _query_params.append(('model_id', model_id))
            
        if version_id is not None:
            
            _query_params.append(('version_id', version_id))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        if error is not None:
            
            _query_params.append(('error', error))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/projects/{project_id}/jobs-by-page',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def projects_project_id_jobs_get(
        self,
        project_id: StrictInt,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PredictionJob]:
        """(Deprecated) List all prediction jobs created using the model. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param project_id: (required)
        :type project_id: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /projects/{project_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._projects_project_id_jobs_get_serialize(
            project_id=project_id,
            id=id,
            name=name,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def projects_project_id_jobs_get_with_http_info(
        self,
        project_id: StrictInt,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PredictionJob]]:
        """(Deprecated) List all prediction jobs created using the model. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param project_id: (required)
        :type project_id: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /projects/{project_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._projects_project_id_jobs_get_serialize(
            project_id=project_id,
            id=id,
            name=name,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def projects_project_id_jobs_get_without_preload_content(
        self,
        project_id: StrictInt,
        id: Optional[StrictInt] = None,
        name: Optional[StrictStr] = None,
        model_id: Optional[StrictInt] = None,
        version_id: Optional[StrictInt] = None,
        status: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """(Deprecated) List all prediction jobs created using the model. This endpoint is deprecated. Please use the corresponding /jobs-by-page endpoint instead.


        :param project_id: (required)
        :type project_id: int
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param model_id:
        :type model_id: int
        :param version_id:
        :type version_id: int
        :param status:
        :type status: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501
        warnings.warn("GET /projects/{project_id}/jobs is deprecated.", DeprecationWarning)

        _param = self._projects_project_id_jobs_get_serialize(
            project_id=project_id,
            id=id,
            name=name,
            model_id=model_id,
            version_id=version_id,
            status=status,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PredictionJob]",
            '404': None
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _projects_project_id_jobs_get_serialize(
        self,
        project_id,
        id,
        name,
        model_id,
        version_id,
        status,
        error,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if project_id is not None:
            _path_params['project_id'] = project_id
        # process the query parameters
        if id is not None:
            
            _query_params.append(('id', id))
            
        if name is not None:
            
            _query_params.append(('name', name))
            
        if model_id is not None:
            
            _query_params.append(('model_id', model_id))
            
        if version_id is not None:
            
            _query_params.append(('version_id', version_id))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        if error is not None:
            
            _query_params.append(('error', error))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/projects/{project_id}/jobs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# Copyright 2020 The Merlin Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from merlin.util import guess_mlp_ui_url, valid_name_check, get_blob_storage_scheme, get_bucket_name, get_artifact_path
import pytest


@pytest.mark.unit
def test_name_check():
    invalid_names = [
        'test-name,', 'test,name', 'test.name'
    ]

    valid_names = [
        'test-name', 'testname'
    ]

    for name in invalid_names:
        result = valid_name_check(name)
        assert result is False
    for name in valid_names:
        result = valid_name_check(name)
        assert result is True


@pytest.mark.unit
def test_get_blob_storage_scheme():
    gcs_artifact_uri = 'gs://some-bucket/mlflow/81/ddd'
    assert get_blob_storage_scheme(gcs_artifact_uri) == 'gs'

    s3_artifact_uri = 's3://some-bucket/mlflow/81/ddd'
    assert get_blob_storage_scheme(s3_artifact_uri) == 's3'


@pytest.mark.unit
def test_get_bucket_name():
    artifact_uri = 'gs://some-bucket/mlflow/81/ddd'
    assert get_bucket_name(artifact_uri) == 'some-bucket'


@pytest.mark.unit
def test_get_artifact_path():
    artifact_uri = 'gs://some-bucket/mlflow/81/ddd'
    assert get_artifact_path(artifact_uri) == 'mlflow/81/ddd'

    double_slash_uri_path = 'gs://some-bucket//mlflow/81/ddd'
    assert get_artifact_path(double_slash_uri_path) == 'mlflow/81/ddd'


@pytest.mark.parametrize("mlp_api_url,expected", [
    ("http://console.mydomain.com/merlin/api", "http://console.mydomain.com/merlin"),
    ("https://console.mydomain.com/merlin/api", "https://console.mydomain.com/merlin"),
    ("console.mydomain.com/merlin/api", "http://console.mydomain.com/merlin"),
])
@pytest.mark.unit
def test_guess_mlp_ui_url(mlp_api_url, expected):
    assert guess_mlp_ui_url(mlp_api_url) == expected



import os
import shutil
from abc import abstractmethod
from dataclasses import dataclass, field
from typing import Any, Dict, List, Optional, Union

import docker
import grpc
import numpy
import pandas
from caraml.upi.v1 import upi_pb2
from docker import APIClient
from merlin.docker.docker import copy_pyfunc_dockerfile, wait_build_complete
from merlin.protocol import Protocol
from merlin.version import VERSION
from mlflow.pyfunc import PythonModel

import mlflow

PYFUNC_EXTRA_ARGS_KEY = "__EXTRA_ARGS__"
PYFUNC_MODEL_INPUT_KEY = "__INPUT__"
PYFUNC_PROTOCOL_KEY = "__PROTOCOL__"
PYFUNC_GRPC_CONTEXT = "__GRPC_CONTEXT__"


class PyFuncModel(PythonModel):
    def load_context(self, context):
        """
        Override method of PythonModel `load_context`. This method load artifacts from context
        that can be used in predict function. This method is called by internal MLflow when an MLflow
        is loaded.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        """
        self.initialize(context.artifacts)
        self._use_kwargs_infer = True

    def predict(self, context, model_input):
        """
        Implementation of PythonModel `predict` method. This method evaluates model input and produces model output.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        :param model_input: A pyfunc-compatible input for the model to evaluate.
        """
        extra_args = model_input.get(PYFUNC_EXTRA_ARGS_KEY, {})
        input = model_input.get(PYFUNC_MODEL_INPUT_KEY, {})
        protocol = model_input.get(PYFUNC_PROTOCOL_KEY, Protocol.HTTP_JSON)

        if protocol == Protocol.HTTP_JSON:
            if extra_args is not None:
                return self._do_http_predict(input, **extra_args)
            return self._do_http_predict(input)
        elif protocol == Protocol.UPI_V1:
            grpc_context = model_input.get(PYFUNC_GRPC_CONTEXT, None)
            grpc_response = self.upiv1_infer(input, grpc_context)
            return grpc_response
        else:
            raise NotImplementedError(f"protocol {protocol} is not supported")

    def _do_http_predict(self, model_input, **kwargs):
        if self._use_kwargs_infer:
            try:
                http_response = self.infer(model_input, **kwargs)
                return http_response
            except TypeError as e:
                if "infer() got an unexpected keyword argument" in str(e):
                    print(
                        "Fallback to the old infer() method, got TypeError exception: {}".format(
                            e
                        )
                    )
                    self._use_kwargs_infer = False
                else:
                    raise e

        http_response = self.infer(model_input)
        return http_response

    @abstractmethod
    def initialize(self, artifacts: dict):
        """
        Implementation of PyFuncModel can specify initialization step which
        will be called one time during model initialization.

        :param artifacts: dictionary of artifacts passed to log_model method
        """
        pass

    @abstractmethod
    def infer(self, request: dict, **kwargs) -> dict:
        """
        Do inference.

        This method MUST be implemented by concrete implementation of
        PyFuncModel to support HTTP_JSON protocol.
        This method accept 'request' which is the body content of incoming
        request.
        Implementation should return inference a json object of response.

        :param request: Dictionary containing incoming request body content
        :param **kwargs: See below.

        :return: Dictionary containing response body

        :keyword arguments:
        * headers (dict): Dictionary containing incoming HTTP request headers
        """
        raise NotImplementedError("infer is not implemented")

    @abstractmethod
    def upiv1_infer(
        self, request: upi_pb2.PredictValuesRequest, context: grpc.ServicerContext
    ) -> upi_pb2.PredictValuesResponse:
        """
        Do inference.

        This method MUST be implemented by concrete implementation of PyFunModel to support UPI_V1 protocol.
        The method accept request in for of PredictValuesRequest proto and should return PredictValuesResponse response proto.

        :param request: Inference request as PredictValuesRequest
        :param context: grpc context
        :return: Prediction result as PredictValuesResponse proto
        """
        raise NotImplementedError("upiv1_infer is not implemented")


@dataclass
class Values:
    columns: List[str]
    data: Union[List[List], numpy.ndarray]

    def to_dict(self):
        data = self.data
        if isinstance(self.data, numpy.ndarray):
            data = self.data.tolist()

        return {"columns": self.columns, "data": data}


@dataclass
class ModelInput:
    # features data for model prediction, the length of data of features must be the same as `prediction_ids` length
    features: Union[Values, pandas.DataFrame]
    # unique identifier of each prediction
    # will be deprecate soon
    prediction_ids: Optional[List[str]] = None
    # entities data is additional data that are not used for prediction, but this data is used to retrieved another features.
    # The length of data of entities must be the same as `prediction_ids` length
    entities: Optional[Union[Values, pandas.DataFrame]] = None
    # session id is identifier for the request
    session_id: str = ""
    # unique identifier for each row in a prediction
    row_ids: List[str] = field(default_factory=lambda: [])

    def _get_row_ids(self) -> List[str]:
        row_ids = self.row_ids
        if len(row_ids) == 0 and self.prediction_ids is not None:
            row_ids = self.prediction_ids
        return row_ids

    def features_dict(self) -> Optional[dict]:
        if self.features is None:
            return None

        val = self.features
        if isinstance(self.features, pandas.DataFrame):
            val = Values(
                self.features.columns.values.tolist(), self.features.values.tolist()
            )

        result = val.to_dict()
        result["row_ids"] = self._get_row_ids()
        return result

    def entities_dict(self) -> Optional[dict]:
        if self.entities is None:
            return None
        val = self.entities
        if isinstance(self.entities, pandas.DataFrame):
            val = Values(
                self.entities.columns.values.tolist(), self.entities.values.tolist()
            )
        result = val.to_dict()
        result["row_ids"] = self._get_row_ids()
        return result


@dataclass
class ModelOutput:
    # predictions contains prediction output from ml_predict
    # it may contains multiple columns e.g for multiclass classification or for binary classification that contains prediction score and label
    # length of the data must be the same as predicion_ids
    predictions: Values
    # unique identifier of each prediction
    # will be deprecate and use `row_ids` instead
    prediction_ids: Optional[List[str]] = None
    # unique identifier for each row in a prediction
    row_ids: List[str] = field(default_factory=lambda: [])

    def predictions_dict(self) -> dict:
        if self.predictions is None:
            return None

        predictions = self.predictions
        if isinstance(self.predictions, pandas.DataFrame):
            predictions = Values(
                self.predictions.columns.values.tolist(),
                self.predictions.values.tolist(),
            )

        result = predictions.to_dict()
        row_ids = self.row_ids
        if len(row_ids) == 0 and self.prediction_ids is not None:
            row_ids = self.prediction_ids

        result["row_ids"] = row_ids
        return result


@dataclass
class PyFuncOutput:
    # final pyfunc response payload when using `HTTP_JSON` protocol
    http_response: Optional[dict] = None
    # final pyfunc response payload when using `UPI_V!` protocol
    upi_response: Optional[upi_pb2.PredictValuesResponse] = None
    # model input contains information about features, entities
    model_input: Optional[ModelInput] = None
    # model output contains information about ml prediction output
    model_output: Optional[ModelOutput] = None

    def get_session_id(self) -> Optional[str]:
        if self.model_input is None:
            return ""
        return self.model_input.session_id

    def contains_prediction_log(self):
        return self.model_input is not None and self.model_output is not None


class PyFuncV3Model(PythonModel):
    def load_context(self, context):
        """
        Override method of PythonModel `load_context`. This method load artifacts from context
        that can be used in predict function. This method is called by internal MLflow when an MLflow
        is loaded.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        """
        self.initialize(context.artifacts)

    def predict(self, context, model_input):
        """
        Implementation of PythonModel `predict` method. This method evaluates model input and produces model output.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        :param model_input: A pyfunc-compatible input for the model to evaluate.
        """
        extra_args = model_input.get(PYFUNC_EXTRA_ARGS_KEY, {})
        input = model_input.get(PYFUNC_MODEL_INPUT_KEY, {})
        protocol = model_input.get(PYFUNC_PROTOCOL_KEY, Protocol.HTTP_JSON)

        if protocol == Protocol.HTTP_JSON:
            if extra_args is not None:
                return self._do_http_predict(input, **extra_args)
            return self._do_http_predict(input)
        elif protocol == Protocol.UPI_V1:
            grpc_context = model_input.get(PYFUNC_GRPC_CONTEXT, None)
            ml_model_input = self.upiv1_preprocess(input, grpc_context)
            ml_model_output = self.infer(ml_model_input)
            final_output = self.upiv1_postprocess(ml_model_output, input)
            return PyFuncOutput(
                upi_response=final_output,
                model_input=ml_model_input,
                model_output=ml_model_output,
            )
        else:
            raise NotImplementedError(f"protocol {protocol} is not supported")

    def _do_http_predict(self, model_input, **kwargs):
        ml_model_input = self.preprocess(model_input, **kwargs)
        ml_model_output = self.infer(ml_model_input)
        final_output = self.postprocess(ml_model_output, model_input)

        return PyFuncOutput(
            http_response=final_output,
            model_input=ml_model_input,
            model_output=ml_model_output,
        )

    @abstractmethod
    def initialize(self, artifacts: dict):
        """
        Implementation of PyFuncModel can specify initialization step which
        will be called one time during model initialization.

        :param artifacts: dictionary of artifacts passed to log_model method
        """
        pass

    @abstractmethod
    def preprocess(self, request: dict, **kwargs) -> ModelInput:
        """
        preprocess is the method that doing preprocessing before calling the ml framework for prediction.
        This method is called when user use HTTP_JSON protocol
        :param request: raw input to the model (dict)
        :return: model input, this model input must already have all the features that required for model prediction
        """
        raise NotImplementedError("preprocess is not implemented")

    @abstractmethod
    def infer(self, model_input: ModelInput) -> ModelOutput:
        """
        infer is the method that will call the respective ml framework to do prediction.
        Since there are various types that supported by each ml framework, user must do conversion from the given model input into acceptable input for the model
        :param model_input: ModelInput that is produced by the `preprocess` method
        :return: model output
        """
        raise NotImplementedError("infer is not implemented")

    @abstractmethod
    def postprocess(self, model_output: ModelOutput, request: dict) -> dict:
        """
        postprocess is the method that is caled after `infer`, the main function of this method is to do postprocessing
        that may including build overall pyfunc response payload, additional computation based on the model output
        :param model_output: the output of the `infer` function
        :param request: raw request payload
        :return: final payload in dictionary type
        """
        raise NotImplementedError("postprocess is not implemented")

    @abstractmethod
    def upiv1_preprocess(
        self, request: upi_pb2.PredictValuesRequest, context: grpc.ServicerContext
    ) -> ModelInput:
        """
        upiv1_preprocess is the preprocessing method that only applicable for UPI_V1 protocol.
        basically the method is the same with `preprocess` the difference is on the type of the incoming request
        for `upiv1_preprocess` the type of request is `PredictValuesRequest`
        :param request: raw request payload
        :param context: grpc request context
        :return: model input
        """
        raise NotImplementedError("upiv1_preprocess is not implemented")

    @abstractmethod
    def upiv1_postprocess(
        self, model_output: ModelOutput, request: upi_pb2.PredictValuesRequest
    ) -> upi_pb2.PredictValuesResponse:
        """
        upiv1_postprocess is the postprocessing method that only applicable for UPI_V1 protocol.
        :param model_output: the output of the `infer` function
        :param request: raw request payload
        :return: final payload in `PredictValuesResponse` type
        """
        raise NotImplementedError("upiv1_postprocess is not implemented")


class PyFuncV2Model(PythonModel):
    def load_context(self, context):
        """
        Override method of PythonModel `load_context`. This method load artifacts from context
        that can be used in predict function. This method is called by internal MLflow when an MLflow
        is loaded.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        """
        self.initialize(context.artifacts)

    def predict(self, context, model_input):
        """
        Implementation of PythonModel `predict` method. This method evaluates model input and produces model output.

        :param context: A :class:`~PythonModelContext` instance containing artifacts that the model
                        can use to perform inference
        :param model_input: A pyfunc-compatible input for the model to evaluate.
        """
        return self.infer(model_input)

    def initialize(self, artifacts: dict):
        """
        Implementation of PyFuncModel can specify initialization step which
        will be called one time during model initialization.

        :param artifacts: dictionary of artifacts passed to log_model method
        """
        pass

    def infer(
        self, model_input: pandas.DataFrame
    ) -> Union[numpy.ndarray, pandas.Series, pandas.DataFrame]:
        """
        Infer method is the main method that will be called when calculating
        the inference result for both online prediction and batch
        prediction. The method accepts pandas Dataframe and returns either
        another panda Dataframe / pandas Series / ndarray of the same length
        as the input. In the batch prediction case the model_input will
        contain an arbitrary partition of the whole dataset that the user
        defines as the data source. As such, it is advisable not to do
        aggregation within the infer method, as it will be incorrect since
        it will only apply to the partition in contrary to the whole dataset.

        :param model_input: input to the model (pandas.DataFrame)
        :return: inference result as numpy.ndarray or pandas.Series or pandas.DataFrame

        """
        raise NotImplementedError("infer is not implemented")


def run_pyfunc_model(
    model_instance: Any,
    conda_env: str,
    code_dir: List[str] = None,
    artifacts: Dict[str, str] = None,
    pyfunc_base_image: str = None,
    port: int = 8080,
    env_vars: Dict[str, str] = None,
    protocol: Protocol = Protocol.HTTP_JSON,
    debug: bool = False,
):
    """
    Run pyfunc model locally using Docker. The function will log the model artifacts onto local mlflow, build a docker image, and run the container locally.

    :param model_instance: instance of python function model
    :param conda_env: path to conda env.yaml file
    :param code_dir: additional code directory that will be loaded with ModelType.PYFUNC model
    :param artifacts: dictionary of artifact that will be stored together with the model. This will be passed to PythonModel.initialize. Example: {"config": "config/staging.yaml"}
    :param pyfunc_base_image: base image for building pyfunc model
    :param port: port to expose the model
    :param env_vars: dictionary of environment variables to be passed to the server
    :param protocol: protocol to be used by the deployed model (default: HTTP_JSON)
    :param debug: flag to enable debug mode that will print docker build log
    """

    model_name = str.lower(model_instance.__class__.__name__)

    # Log model to local mlflow
    print("Logging model to local MLflow")
    tracking_uri = f"file:///tmp/merlin/pyfunc-models"
    mlflow.set_tracking_uri(tracking_uri)
    experiment = mlflow.set_experiment(model_name)

    model_info = mlflow.pyfunc.log_model(
        artifact_path="model",
        python_model=model_instance,
        conda_env=conda_env,
        code_path=code_dir,
        artifacts=artifacts,
    )

    context_path = experiment.artifact_location
    if "file://" in context_path:
        context_path = context_path.replace("file://", "")

    dependencies_path = f"{context_path}/env.yaml"
    shutil.copy(conda_env, dependencies_path)

    artifact_path = f"{model_info.run_id}/artifacts/model"

    run_pyfunc_local_server(
        context_path=context_path,
        dependencies_path=dependencies_path,
        artifact_path=artifact_path,
        model_name=model_name,
        model_version="dev",
        pyfunc_base_image=pyfunc_base_image,
        port=port,
        env_vars=env_vars,
        protocol=protocol,
        debug=debug,
    )


def run_pyfunc_local_server(
    context_path: str,
    dependencies_path: str,
    artifact_path: str,
    model_name: str,
    model_version: str,
    pyfunc_base_image: str = None,
    port: int = 8080,
    env_vars: Dict[str, str] = None,
    protocol: Protocol = Protocol.HTTP_JSON,
    debug: bool = False,
):
    if pyfunc_base_image is None:
        if "dev" in VERSION or "0.0.0" in VERSION:
            pyfunc_base_image = "ghcr.io/caraml-dev/merlin/merlin-pyfunc-base:0.41.0"
        else:
            pyfunc_base_image = (
                f"ghcr.io/caraml-dev/merlin/merlin-pyfunc-base:{VERSION}"
            )

    dockerfile_path = copy_pyfunc_dockerfile(context_path)

    _clone_merlin_repo(context_path)

    image_tag = f"{model_name}-{model_version}"

    print(f"Building Docker image {image_tag}")
    if debug:
        print("Context path:", context_path)
        print("Dockerfile path:", dockerfile_path)
        print("Dependencies path:", dependencies_path)
        print("Model artifacts path:", artifact_path)

    _build_image(
        image_tag=image_tag,
        context_path=context_path,
        dependencies_path=dependencies_path,
        artifact_path=artifact_path,
        pyfunc_base_image=pyfunc_base_image,
        dockerfile_path=dockerfile_path,
        debug=debug,
    )

    print("Running PyFunc local server")
    _run_container(
        image_tag=image_tag,
        model_name=model_name,
        model_version=model_version,
        model_full_name=f"{model_name}-{model_version}",
        port=port,
        env_vars=env_vars,
        protocol=protocol,
    )


def _clone_merlin_repo(context_path: str):
    # Can't be imported at module level because the initialization will fail when the git executable
    # does not exists.
    from git import Repo

    repo_url = "https://github.com/caraml-dev/merlin.git"
    repo_path = f"{context_path}/merlin"
    if not os.path.isdir(repo_path):
        repo = Repo.clone_from(repo_url, repo_path)
        if "dev" in VERSION or "0.0.0" in VERSION:
            repo.git.checkout("main")
        else:
            repo.git.checkout(f"v{VERSION}")


def _build_image(
    image_tag,
    context_path,
    dependencies_path,
    artifact_path,
    pyfunc_base_image,
    dockerfile_path,
    debug,
):
    docker_api_client = APIClient()
    logs = docker_api_client.build(
        path=context_path,
        tag=image_tag,
        buildargs={
            "BASE_IMAGE": pyfunc_base_image,
            "MODEL_DEPENDENCIES_URL": os.path.basename(dependencies_path),
            "MODEL_ARTIFACTS_URL": artifact_path,
        },
        dockerfile=os.path.basename(dockerfile_path),
        decode=True,
    )

    wait_build_complete(logs, debug)


def _run_container(
    image_tag,
    model_name,
    model_version,
    model_full_name,
    port,
    env_vars: Dict[str, str] = None,
    protocol: Protocol = Protocol.HTTP_JSON,
):
    docker_client = docker.from_env()

    # Stop all previous containers to avoid port conflict
    started_containers = docker_client.containers.list(
        filters={"name": model_full_name}
    )
    for started_container in started_containers:
        started_container.remove(force=True)

    if env_vars is None:
        env_vars = {}

    env_vars["CARAML_HTTP_PORT"] = "8080"
    env_vars["CARAML_GRPC_PORT"] = "9000"
    env_vars["CARAML_MODEL_NAME"] = model_name
    env_vars["CARAML_MODEL_VERSION"] = model_version
    env_vars["CARAML_MODEL_FULL_NAME"] = model_full_name
    env_vars["WORKERS"] = "1"

    ports = {"8080/tcp": port}
    if protocol == Protocol.UPI_V1:
        env_vars["CARAML_PROTOCOL"] = protocol.value
        ports = {"9000/tcp": port}

    try:
        container = docker_client.containers.run(
            image=image_tag,
            name=model_name,
            labels={"managed-by": "merlin"},
            ports=ports,
            environment=env_vars,
            detach=True,
            remove=True,
        )

        # continously print docker log until the process is interrupted
        for log in container.logs(stream=True):
            print(log)
    finally:
        if container is not None:
            container.remove(force=True)



#!/usr/bin/env python
# Copyright 2020 The Merlin Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import imp
import os

from setuptools import find_packages, setup

version = imp.load_source(
    "merlin.version", os.path.join("merlin", "version.py")
).VERSION

with open("requirements.txt") as f:
    REQUIRE = f.read().splitlines()

with open("requirements_test.txt") as f:
    TESTS_REQUIRE = f.read().splitlines()

setup(
    name="merlin-sdk",
    version=version,
    description="Python SDK for Merlin",
    url="https://github.com/caraml-dev/merlin",
    author="Merlin",
    packages=find_packages(),
    package_data={"merlin": ["docker/pyfunc.Dockerfile", "docker/standard.Dockerfile"]},
    zip_safe=True,
    install_requires=REQUIRE,
    setup_requires=["setuptools_scm"],
    tests_require=TESTS_REQUIRE,
    extras_require={"test": TESTS_REQUIRE},
    python_requires=">=3.8,<3.11",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    entry_points="""
        [console_scripts]
        merlin=merlin.merlin:cli
    """,
)



# flake8: noqa

# import apis into api package
from client.api.alert_api import AlertApi
from client.api.endpoint_api import EndpointApi
from client.api.environment_api import EnvironmentApi
from client.api.log_api import LogApi
from client.api.model_endpoints_api import ModelEndpointsApi
from client.api.model_schema_api import ModelSchemaApi
from client.api.models_api import ModelsApi
from client.api.prediction_jobs_api import PredictionJobsApi
from client.api.project_api import ProjectApi
from client.api.secret_api import SecretApi
from client.api.standard_transformer_api import StandardTransformerApi
from client.api.version_api import VersionApi
from client.api.version_image_api import VersionImageApi

